Module query

Module query 

Functions

evaluate_where
Evaluate a MongoDB-style WHERE clause against a single document.
exclude
Remove specified fields from a document (the inverse of project).
get_nested_value
Read a value at any depth from a JSON object using a dot-notation path.
project
Select only the specified fields from a document (field projection).