Skip to main contentModule engine
Source - AsyncDiskStorage
- High-performance async disk writer.
- Db
- The central database handle. Cheap to clone — all clones share the same state.
- EncryptedStorage
- Transparent encryption wrapper around any StorageBackend.
- LogEntry
- The atomic unit of data in MoltenDB’s append-only log.
- SyncDiskStorage
- High-durability synchronous disk writer.
- DbError
- All possible errors that can occur in the database engine.
- StorageBackend
- The core storage abstraction. Implement this trait to add a new storage backend.