Module engine

Module engine 

Structs

Db
The central database handle. Cheap to clone — all clones share the same state.
EncryptedStorage
Transparent encryption wrapper around any StorageBackend.

Enums

DbError
All possible errors that can occur in the database engine.

Traits

StorageBackend
The core storage abstraction. Implement this trait to add a new storage backend.